package com.xkrs.service;

import com.xkrs.dao.FirePointDao;
import com.xkrs.model.entity.FirePointEntity;
import com.xkrs.model.qo.FirePointQo;
import com.xkrs.model.vo.AppTaskBodyVo;
import org.springframework.web.multipart.MultipartFile;

import java.io.IOException;
import java.util.List;
import java.util.Map;

/**
 * @author XinYi Song
 */
public interface FirePointService {

    /**
     * 添加火点信息
     * @param firePointQo
     * @return
     */
    FirePointEntity insertFirePoint(FirePointQo firePointQo);

    /**
     * 查询今天的火点信息
     * @param
     * @return
     */
    List<FirePointEntity> selectTodayFirePoint(String countyCode);

    /**
     * 动态多条件查询火点信息(省)
     * @param proCode
     * @param cityCode
     * @param satelliteType
     * @param landType
     * @param startTime
     * @param endTime
     * @return
     */
    List<FirePointEntity> selectFirePoint(String proCode,String cityCode,String satelliteType,String landType,String startTime,String endTime);


    /**
     * 动态多条件查询火点信息(市)
     * @param cityCodeOne    市编码
     * @param cityCode       县编码
     * @param satelliteType
     * @param landType
     * @param startTime
     * @param endTime
     * @return
     */
    List<FirePointEntity> selectFirePointByCity(String cityCodeOne,String cityCode,String satelliteType,String landType,String startTime,String endTime);

    /**
     * 动态多条件查询火点信息(县)
     * @param cityCode       县编码
     * @param satelliteType
     * @param landType
     * @param startTime
     * @param endTime
     * @return
     */
    List<FirePointEntity> selectFirePointByCounty(String cityCode,String satelliteType,String landType,String startTime,String endTime);

    /**
     * 根据火点编码修改火点的状态（预警）
     * @param fireCode
     * @param fireType
     * @param token
     * @return
     */
    String updateTypeByFireCode(String fireCode,String fireType,String token);

    /**
     * 提交核查任务信息
     * @param files
     * @param appTaskBodyVo
     * @return
     * @throws IOException
     */
    String insertAppTask(MultipartFile[] files, AppTaskBodyVo appTaskBodyVo) throws IOException;

    /**
     * 根据火点编码查询任务信息
     * @param fireCode
     * @param
     * @return
     * @throws Exception
     */
    String selectAppTask(String fireCode) throws Exception;

    /**
     * 查询近一周天的火点信息
     * @return
     */
    List<FirePointEntity> selectFirePointBetweenSeven();

    /**
     * 查询近一个月的火点信息
     * @return
     */
    List<FirePointEntity> selectFirePointByMonth();

    /**
     * 查询近一个月的火点数量
     * @return
     */
    String selectFirePointNumMonth();

    /**
     * 查询近一天的火点数量
     * @return
     */
    String selectFirePointNumDay();

    /**
     * 查询
     * @return
     */
    String selectFirePointNumWeek();

    /**
     * 查询该省所有的市
     * @return
     */
    List<Map<String,Object>> selectCityName();
}
